@@ -1,22 +1,31 @@
 context("coercion")
 
 test_that("coercion in", {
-  expect_identical(as.hms(0.5 * 86400), hms(hours = 12))
-  expect_identical(as.hms(-0.25 * 86400), hms(hours = -6))
-  expect_hms_equal(as.hms("12:34:56"), hms(56, 34, 12))
-  expect_hms_equal(as.hms(strptime("12:34:56", format = "%H:%M:%S", tz = "UTC"), tz = "UTC"),
+  expect_identical(as_hms(0.5 * 86400), hms(hours = 12))
+  expect_identical(as_hms(-0.25 * 86400), hms(hours = -6))
+  expect_hms_equal(as_hms("12:34:56"), hms(56, 34, 12))
+  expect_hms_equal(as_hms(strptime("12:34:56", format = "%H:%M:%S", tz = "UTC")),
                    hms(56, 34, 12))
-  expect_hms_equal(as.hms(strptime("12:34:56", format = "%H:%M:%S", tz = "CEST"), tz = "CEST"),
+  expect_hms_equal(as_hms(strptime("12:34:56", format = "%H:%M:%S", tz = "CEST")),
                    hms(56, 34, 12))
-  expect_hms_equal(as.hms(strptime("12:34:56", format = "%H:%M:%S", tz = "PST8PDT"), tz = "PST8PDT"),
+  expect_hms_equal(as_hms(strptime("12:34:56", format = "%H:%M:%S", tz = "PST8PDT")),
+                   hms(56, 34, 12))
+  expect_hms_equal(as_hms(as.POSIXct(strptime("12:34:56", format = "%H:%M:%S", tz = "UTC"))),
+                   hms(56, 34, 12))
+  expect_hms_equal(as_hms(as.POSIXct(strptime("12:34:56", format = "%H:%M:%S", tz = "CEST"))),
+                   hms(56, 34, 12))
+  expect_hms_equal(as_hms(as.POSIXct(strptime("12:34:56", format = "%H:%M:%S", tz = "PST8PDT"))),
                    hms(56, 34, 12))
 
   now <- Sys.time()
   now_lt <- as.POSIXlt(now)
-  expect_hms_equal(as.hms(now), hms(now_lt$sec, now_lt$min, now_lt$hour))
-  expect_hms_equal(as.hms(now_lt), as.hms(now))
+  expect_hms_equal(as_hms(now), hms(now_lt$sec, now_lt$min, now_lt$hour))
+  expect_hms_equal(as_hms(now_lt), as_hms(now))
 
-  expect_error(as.hms(FALSE))
+  expect_error(as_hms(FALSE))
+
+  x <- c("12:34:56", "ab:cd:ef")
+  expect_condition(hms::as_hms(x), class = "hms_lossy_cast")
 })
 
 test_that("coercion out", {
